=======
Authors
=======

Maintainers and core contributors are listed below:

Authors
-------

- `Matthew R. Carbone <https://www.bnl.gov/staff/mcarbone>`__ [#f1]_
- Stepan Fomichev [#f1]_
- `John Sous <https://www.johnsous.com>`__ [#f2]_ 

Other investigators
-------------------

- `Mona Berciu <https://phas.ubc.ca/~berciu/>`__
- `Andrew J. Millis <https://www.simonsfoundation.org/people/andrew-millis/>`__
- `David R. Reichman <http://www.columbia.edu/cu/chemistry/groups/reichman/>`__


Contributors
------------

- Noah Bright


----

.. [#f1] Maintainer
.. [#f2] Principal investigator
